@@ -109,7 +109,7 @@ pref("browser.chrome.image_icons.max_size", 1024);
 pref("accessibility.browsewithcaret", false);
 pref("accessibility.warn_on_browsewithcaret", true);
 
-//@line 113 "/mozdisk/112build/mozilla/modules/libpref/src/init/all.js"
+//@line 113 "/home/hafi/seam/release/gtk1/1.1.6/mozilla/modules/libpref/src/init/all.js"
 // Tab focus model bit field:
 // 1 focuses text controls, 2 focuses other form elements, 4 adds links.
 // Most users will want 1, 3, or 7.
@@ -117,7 +117,7 @@ pref("accessibility.warn_on_browsewithcaret", true);
 // unless accessibility.tabfocus is set by the user.
 pref("accessibility.tabfocus", 7);
 pref("accessibility.tabfocus_applies_to_xul", false);
-//@line 124 "/mozdisk/112build/mozilla/modules/libpref/src/init/all.js"
+//@line 124 "/home/hafi/seam/release/gtk1/1.1.6/mozilla/modules/libpref/src/init/all.js"
 
 pref("accessibility.usetexttospeech", "");
 pref("accessibility.usebrailledisplay", "");
@@ -487,7 +487,7 @@ pref("network.protocol-handler.external.data", false);
 pref("network.protocol-handler.external.ms-help", false);
 pref("network.protocol-handler.external.shell", false);
 pref("network.protocol-handler.external.vnd.ms.radio", false);
-//@line 496 "/mozdisk/112build/mozilla/modules/libpref/src/init/all.js"
+//@line 496 "/home/hafi/seam/release/gtk1/1.1.6/mozilla/modules/libpref/src/init/all.js"
 pref("network.protocol-handler.external.disk", false);
 pref("network.protocol-handler.external.disks", false);
 pref("network.protocol-handler.external.afp", false);
@@ -613,6 +613,7 @@ pref("network.IDN.whitelist.kr", true);
 pref("network.IDN.whitelist.li", true);
 pref("network.IDN.whitelist.lt", true);
 pref("network.IDN.whitelist.no", true);
+pref("network.IDN.whitelist.pl", true);
 pref("network.IDN.whitelist.se", true);
 pref("network.IDN.whitelist.sh", true);
 pref("network.IDN.whitelist.th", true);
@@ -684,7 +685,7 @@ pref("network.negotiate-auth.gsslib", "");
 // Specify if the gss lib comes standard with the OS
 pref("network.negotiate-auth.using-native-gsslib", true);
 
-//@line 698 "/mozdisk/112build/mozilla/modules/libpref/src/init/all.js"
+//@line 699 "/home/hafi/seam/release/gtk1/1.1.6/mozilla/modules/libpref/src/init/all.js"
 
 // The following prefs are used to enable automatic use of the operating
 // system's NTLM implementation to silently authenticate the user with their
@@ -832,7 +833,7 @@ pref("mousewheel.withmetakey.sysnumlines",true);
 
 // on platforms where scroll messages differ between horizontal scroll
 // and back/forward button events we can activate them by default
-//@line 880 "/mozdisk/112build/mozilla/modules/libpref/src/init/all.js"
+//@line 881 "/home/hafi/seam/release/gtk1/1.1.6/mozilla/modules/libpref/src/init/all.js"
 // disable horizontal scrolling to be able to use back/forward buttons
 pref("mousewheel.horizscroll.withnokey.action",2);
 pref("mousewheel.horizscroll.withnokey.numlines",-1);
@@ -849,7 +850,7 @@ pref("mousewheel.horizscroll.withaltkey.sysnumlines",false);
 pref("mousewheel.horizscroll.withmetakey.action",2);
 pref("mousewheel.horizscroll.withmetakey.numlines",-1);
 pref("mousewheel.horizscroll.withmetakey.sysnumlines",false);
-//@line 897 "/mozdisk/112build/mozilla/modules/libpref/src/init/all.js"
+//@line 898 "/home/hafi/seam/release/gtk1/1.1.6/mozilla/modules/libpref/src/init/all.js"
 
 pref("profile.confirm_automigration",true);
 // profile.migration_behavior determines how the profiles root is set
@@ -992,15 +993,15 @@ pref("dom.max_script_run_time", 10);
 
 pref("svg.enabled", true);
 
-//@line 1370 "/mozdisk/112build/mozilla/modules/libpref/src/init/all.js"
+//@line 1371 "/home/hafi/seam/release/gtk1/1.1.6/mozilla/modules/libpref/src/init/all.js"
 
-//@line 1562 "/mozdisk/112build/mozilla/modules/libpref/src/init/all.js"
+//@line 1563 "/home/hafi/seam/release/gtk1/1.1.6/mozilla/modules/libpref/src/init/all.js"
 
-//@line 1751 "/mozdisk/112build/mozilla/modules/libpref/src/init/all.js"
+//@line 1752 "/home/hafi/seam/release/gtk1/1.1.6/mozilla/modules/libpref/src/init/all.js"
 
-//@line 1840 "/mozdisk/112build/mozilla/modules/libpref/src/init/all.js"
+//@line 1841 "/home/hafi/seam/release/gtk1/1.1.6/mozilla/modules/libpref/src/init/all.js"
 
-//@line 1843 "/mozdisk/112build/mozilla/modules/libpref/src/init/all.js"
+//@line 1844 "/home/hafi/seam/release/gtk1/1.1.6/mozilla/modules/libpref/src/init/all.js"
 // Handled differently under Mac/Windows
 pref("network.hosts.smtp_server", "localhost");
 pref("network.hosts.pop_server", "pop");
@@ -1073,7 +1074,7 @@ pref("font.allow_double_byte_special_chars", true);
 
 // ar
 
-//@line 1976 "/mozdisk/112build/mozilla/modules/libpref/src/init/all.js"
+//@line 1977 "/home/hafi/seam/release/gtk1/1.1.6/mozilla/modules/libpref/src/init/all.js"
 pref("font.name.serif.el", "misc-fixed-iso8859-7");
 pref("font.name.sans-serif.el", "misc-fixed-iso8859-7");
 pref("font.name.monospace.el", "misc-fixed-iso8859-7");
@@ -1131,7 +1132,7 @@ pref("font.name.sans-serif.zh-HK", "-arphic-Ming for ISO10646-big5hkscs-0");
 pref("font.name.monospace.zh-HK", "-arphic-Ming for ISO10646-big5hkscs-0");
 
 // zh-TW
-//@line 2035 "/mozdisk/112build/mozilla/modules/libpref/src/init/all.js"
+//@line 2036 "/home/hafi/seam/release/gtk1/1.1.6/mozilla/modules/libpref/src/init/all.js"
 
 pref("font.default.ar", "sans-serif");
 pref("font.size.variable.ar", 16);
@@ -1349,11 +1350,15 @@ pref("print.postscript.nativefont.zh-CN",          "");
 pref("print.postscript.nativefont.zh-TW",          "");
 pref("print.postscript.nativefont.zh-HK",          "");
 
-//@line 2255 "/mozdisk/112build/mozilla/modules/libpref/src/init/all.js"
+//@line 2256 "/home/hafi/seam/release/gtk1/1.1.6/mozilla/modules/libpref/src/init/all.js"
 
-//@line 2323 "/mozdisk/112build/mozilla/modules/libpref/src/init/all.js"
+//@line 2324 "/home/hafi/seam/release/gtk1/1.1.6/mozilla/modules/libpref/src/init/all.js"
 
-//@line 2349 "/mozdisk/112build/mozilla/modules/libpref/src/init/all.js"
+//@line 2350 "/home/hafi/seam/release/gtk1/1.1.6/mozilla/modules/libpref/src/init/all.js"
 
-//@line 2369 "/mozdisk/112build/mozilla/modules/libpref/src/init/all.js"
+//@line 2370 "/home/hafi/seam/release/gtk1/1.1.6/mozilla/modules/libpref/src/init/all.js"
 
+//@line 2378 "/home/hafi/seam/release/gtk1/1.1.6/mozilla/modules/libpref/src/init/all.js"
+
+//@line 2380 "/home/hafi/seam/release/gtk1/1.1.6/mozilla/modules/libpref/src/init/all.js"
+pref("network.gnomevfs.supported-protocols", "smb:,sftp:");
